#
# spec file for package udunits2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 0

Name:           udunits2
Version:        2.2.28
Release:        1.13
Summary:        A library for manipulating units of physical quantities
License:        MIT
Group:          Productivity/Scientific/Math
URL:            https://www.unidata.ucar.edu/software/udunits/
Source0:        ftp://ftp.unidata.ucar.edu/pub/udunits/udunits-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  info
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  CUnit-devel
BuildRequires:  expat-devel
%define ext_info .gz
%else
BuildRequires:  cunit-devel
BuildRequires:  libexpat-devel
%endif

%description
The Unidata units utility, udunits, supports conversion of unit specifications
between formatted and binary forms, arithmetic manipulation of unit
specifications, and conversion of values between compatible scales of
measurement. A unit is the amount by which a physical quantity is measured. For
example:

                  Physical Quantity   Possible Unit
                  _________________   _____________
                        time              weeks
                      distance         centimeters
                        power             watts

This utility works interactively and has two modes. In one mode, both an input
and output unit specification are given, causing the utility to print the
conversion between them. In the other mode, only an input unit specification is
given. This causes the utility to print the definition -- in standard units --
of the input unit.

%package -n lib%{name}-%{soname}
Summary:        Libraries for %{name}
Group:          Development/Libraries/C and C++

%package devel
Summary:        Headers and development libraries for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Conflicts:      udunits < %{version}

%package -n udunits-compat
Summary:        Udunits2 compatibility layer for udunits v1 API
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}-%{release}
Obsoletes:      udunits < %{version}
Provides:       udunits = %{version}

%package -n udunits-compat-devel
Summary:        Udunits2 compatibility layer for udunits v1 API
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}-%{release}
Requires:       udunits-compat = %{version}-%{release}
Obsoletes:      udunits-devel < %{version}
Provides:       udunits-devel = %{version}

%description -n lib%{name}-%{soname}
This package contains the runtime libraries for %{name}.

%description devel
This package contains the files needed for compiling programs using
the %{name} library.

%description -n udunits-compat
A compatibility layer allowing applications written for libudunits to
work with libudunits2.

%description -n udunits-compat-devel
This package contains the files needed for compiling programs using
the udunits2 compatibility library.

%prep
%setup -q -n udunits-%{version}

%build
%configure --docdir=%{_docdir}/%{name} --disable-static
%make_build

%install
%make_install install-html install-pdf

# Install info file
mkdir -p %{buildroot}%{_infodir}/
install -p -m0644 %{name}.info %{buildroot}%{_infodir}

#---Installation with custom docdir does not really work:
pushd %{buildroot}%{_docdir}/%{name}
rm -f *.xml
for f in %{buildroot}%{_datadir}/udunits/*.xml; do
  ln -sr "$f" .
done
popd
#---We provide compat symlinks to provide udunits v1 API:
pushd %{buildroot}%{_libdir}
for f in libudunits2.so*; do
  ln -s "$f" "libudunits.so${f#*.so}"
done
popd
#---cleanup
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_infodir}/dir

%check
%make_build check

%post
install-info %{_infodir}/%{name}.info %{_infodir}/dir || :

%post   -n lib%{name}-%{soname} -p /sbin/ldconfig
%postun -n lib%{name}-%{soname} -p /sbin/ldconfig
%post   -n udunits-compat       -p /sbin/ldconfig
%postun -n udunits-compat       -p /sbin/ldconfig
%preun
if [ $1 = 0 ] ; then
  install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir || :
fi

%files
%{_bindir}/%{name}
%{_datadir}/udunits/
%{_infodir}/%{name}*.info%{?ext_info}
%{_docdir}/%{name}

%files -n lib%{name}-%{soname}
%license COPYRIGHT
%{_libdir}/libudunits2.so.*

%files devel
%{_includedir}/converter.h
%{_includedir}/udunits2.h
%{_libdir}/libudunits2.so

%files -n udunits-compat
%{_libdir}/libudunits.so.*

%files -n udunits-compat-devel
%{_includedir}/udunits.h
%{_libdir}/libudunits.so

%changelog
* Tue Dec 29 2020 Manfred Schwarb <manfred99@gmx.ch>
- install docs into default directory %%_docdir/udunits2
- Update to version 2.2.28:
  * build changes
- Update to version 2.2.27:
  * support better shared libraries under Windows
  * build changes
  * lot of cleanup
  * replace the use of default_udunits2_xml_path() with public API function ut_get_path_xml
  * replace assert in galileanNew() with conditional and error-return
  * catch input value is out of range in ut_encode_clock()
  * printTimestamp(): Corrected buffer overflow bug
  * fix formatting bug in ut_format()
  * documentation improvements
  * rename c99_snprintf() to udunits_snprintf() and c99_vsnprintf() to
    udunits_vsnprintf() to avoid name-clash with HDF5
* Sat Nov 28 2020 Manfred Schwarb <manfred99@gmx.ch>
- split off library package libudunits2-0
- enable unit tests for non-openSUSE targets
- configure with --disable-static and do no longer manually remove
    static libraries
- use %%make_build and %%make_install to build package
- add "BuildRequires: info"
* Fri Dec  6 2019 manfred99@gmx.ch
- drop static libraries
* Thu Dec 28 2017 manfred99@gmx.ch
- Updated to 2.2.26:
  * CMake build changes
  * Fixed problem with the definition of "(mm2 day-2)/(mm2 day-2)"
  * Fixed bug in the parsing of the have-unit of udunits2
* Fri May 19 2017 manfred99@gmx.ch
- Updated to 2.2.25:
  * Corrected temporal decomposition algorithm in ut_decode_time().
  * Added missing UDUNITS-1 files to the distribution ("lib/udunits.h" and
    "lib/udunits-1.c").
* Fri Mar 17 2017 manfred99@gmx.ch
- Updated to 2.2.24:
  * Added unit "ppv"
  * Fixed utCalendar() in the UDUNITS-1 interface returning 60 seconds.
- Updated to 2.2.23:
  * Added missing comma to snprintf() call under Windows.
- Updated to 2.2.22:
  * Added missing files to distribution for building on Windows.
- Updated to 2.2.21:
  * Corrected construction of the pathname of an imported database file
    under Windows.
* Sun Nov 27 2016 manfred99@gmx.ch
- Updated to 2.2.20
  * modifications for better portability
  * Replaced use of deprecated atof() with strtod()
  * Changed definition and symbol of "astronomical_unit"
  * added tsearch.[ch] for building on Windows
- spec file cleanup
- provide compat packages for API v1 users (udunits)
* Thu Apr  2 2015 ocefpaf@gmail.com
- Updated to 2.2.18
  * Eliminated the use of unistd.h on Windows.
  * Improved support for static builds (i.e., builds that don't produce a
    sharable library).
  * Units Database:
  - Corrected the definition of "dram" and added "fluid_dram".
  - Changed the definition of "molecule" to "1/avogadro_constant".
  - Added comments and human-readable definitions.
  * Program:
  - Removed latent bug on Windows in determining the name of the program.
  * Misc:
  - Removed lint discovered by Coverity.
* Thu Dec 11 2014 ocefpaf@gmail.com
- Updated to 2.2.17
  * Modified the lexical scanner to accept the use of "ref" in an offset
    time-unit specification (e.g., "seconds ref 1970-01-01") in order to be
    compatible with version 2.1. Added concomitant test to unit-tests.
* Mon Jul 14 2014 ocefpaf@gmail.com
- Updated to 2.2.16
  * Added units "molecule" (for conversion with "mole") and "bit".
  * Added "-H have" and "-W want" options.
  * Added "nucleon" (alias "nuc") to database as "mole/(avogadro's number)" to
    support units like "Mev/nucleon".
  * Added "octet" and "byte" to common units as aliases for the dimensionless
    unit "8". (The unit "bit" was already defined).
